@@ -5,16 +5,16 @@ import logging
 class FluentbitRequestHandler(socketserver.BaseRequestHandler):
 
     def __init__(self, request, client_address, server):
-        # print("create FluentRequestHandler")
         self._log = logging.getLogger("FluentbitRequestHandler")
+        self._log.debug("Init for {}".format(client_address))
         socketserver.BaseRequestHandler.__init__(self, request, client_address, server)
 
     def setup(self):
-        # print("FluentRequestHandler.setup")
+        self._log.debug("setup")
         return socketserver.BaseRequestHandler.setup(self)
 
     def handle(self):
-        # print("FluentRequestHandler.handle")
+        self._log.debug("handle")
         if self.server.get_authentication():
             auth = self.server.get_authentication()()
             authorized = auth.process_authentication(self.request)
@@ -24,14 +24,13 @@ class FluentbitRequestHandler(socketserver.BaseRequestHandler):
         if authorized:
             try:
                 t = self.server.get_transport()()
-                message_bin = t.collect(self.request)
-                t.process(message_bin)
+                for message_bin in t.collect(self.request):
+                    t.process(message_bin)
             except Exception as e:
                 self._log.error("Drop message ({})".format(repr(e)))
-                pass
         else:
             self._log.debug("Authentication failed")
 
     def finish(self):
-        # print("FluentRequestHandler.finish")
+        self._log.debug("finish")
         return socketserver.BaseRequestHandler.finish(self)
\ No newline at end of file
